/**
 * Validate a Mapbox GL style against the style specification. This entrypoint,
 * `maplibre-gl-style-spec/lib/validate_style.min`, is designed to produce as
 * small a browserify bundle as possible by omitting unnecessary functionality
 * and legacy style specifications.
 *
 * @private
 * @param {Object} style The style to be validated.
 * @param {Object} [styleSpec] The style specification to validate against.
 *     If omitted, the latest style spec is used.
 * @returns {Array<ValidationError>}
 * @example
 *   var validate = require('maplibre-gl-style-spec/lib/validate_style.min');
 *   var errors = validate(style);
 */
declare function validateStyleMin(style: any, styleSpec?: {
    $version: number;
    $root: {
        version: {
            required: boolean;
            type: string;
            values: number[];
            doc: string;
            example: number;
        };
        name: {
            type: string;
            doc: string;
            example: string;
        };
        metadata: {
            type: string;
            doc: string;
        };
        center: {
            type: string;
            value: string;
            doc: string;
            example: number[];
        };
        zoom: {
            type: string;
            doc: string;
            example: number;
        };
        bearing: {
            type: string;
            default: number;
            period: number;
            units: string;
            doc: string;
            example: number;
        };
        pitch: {
            type: string;
            default: number;
            units: string;
            doc: string;
            example: number;
        };
        light: {
            type: string;
            doc: string;
            example: {
                anchor: string;
                color: string;
                intensity: number;
            };
        };
        sources: {
            required: boolean;
            type: string;
            doc: string;
            example: {
                "mapbox-streets": {
                    type: string;
                    url: string;
                };
            };
        };
        sprite: {
            type: string;
            doc: string;
            example: string;
        };
        glyphs: {
            type: string;
            doc: string;
            example: string;
        };
        transition: {
            type: string;
            doc: string;
            example: {
                duration: number;
                delay: number;
            };
        };
        layers: {
            required: boolean;
            type: string;
            value: string;
            doc: string;
            example: {
                id: string;
                source: string;
                "source-layer": string;
                type: string;
                paint: {
                    "fill-color": string;
                };
            }[];
        };
    };
    sources: {
        "*": {
            type: string;
            doc: string;
        };
    };
    source: string[];
    source_vector: {
        type: {
            required: boolean;
            type: string;
            values: {
                vector: {
                    doc: string;
                };
            };
            doc: string;
        };
        url: {
            type: string;
            doc: string;
        };
        tiles: {
            type: string;
            value: string;
            doc: string;
        };
        bounds: {
            type: string;
            value: string;
            length: number;
            default: number[];
            doc: string;
        };
        scheme: {
            type: string;
            values: {
                xyz: {
                    doc: string;
                };
                tms: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
        };
        minzoom: {
            type: string;
            default: number;
            doc: string;
        };
        maxzoom: {
            type: string;
            default: number;
            doc: string;
        };
        attribution: {
            type: string;
            doc: string;
        };
        promoteId: {
            type: string;
            doc: string;
        };
        volatile: {
            type: string;
            default: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    android: string;
                    ios: string;
                };
            };
        };
        "*": {
            type: string;
            doc: string;
        };
    };
    source_raster: {
        type: {
            required: boolean;
            type: string;
            values: {
                raster: {
                    doc: string;
                };
            };
            doc: string;
        };
        url: {
            type: string;
            doc: string;
        };
        tiles: {
            type: string;
            value: string;
            doc: string;
        };
        bounds: {
            type: string;
            value: string;
            length: number;
            default: number[];
            doc: string;
        };
        minzoom: {
            type: string;
            default: number;
            doc: string;
        };
        maxzoom: {
            type: string;
            default: number;
            doc: string;
        };
        tileSize: {
            type: string;
            default: number;
            units: string;
            doc: string;
        };
        scheme: {
            type: string;
            values: {
                xyz: {
                    doc: string;
                };
                tms: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
        };
        attribution: {
            type: string;
            doc: string;
        };
        volatile: {
            type: string;
            default: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    android: string;
                    ios: string;
                };
            };
        };
        "*": {
            type: string;
            doc: string;
        };
    };
    source_raster_dem: {
        type: {
            required: boolean;
            type: string;
            values: {
                "raster-dem": {
                    doc: string;
                };
            };
            doc: string;
        };
        url: {
            type: string;
            doc: string;
        };
        tiles: {
            type: string;
            value: string;
            doc: string;
        };
        bounds: {
            type: string;
            value: string;
            length: number;
            default: number[];
            doc: string;
        };
        minzoom: {
            type: string;
            default: number;
            doc: string;
        };
        maxzoom: {
            type: string;
            default: number;
            doc: string;
        };
        tileSize: {
            type: string;
            default: number;
            units: string;
            doc: string;
        };
        attribution: {
            type: string;
            doc: string;
        };
        encoding: {
            type: string;
            values: {
                terrarium: {
                    doc: string;
                };
                mapbox: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
        };
        volatile: {
            type: string;
            default: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    android: string;
                    ios: string;
                };
            };
        };
        "*": {
            type: string;
            doc: string;
        };
    };
    source_geojson: {
        type: {
            required: boolean;
            type: string;
            values: {
                geojson: {
                    doc: string;
                };
            };
            doc: string;
        };
        data: {
            type: string;
            doc: string;
        };
        maxzoom: {
            type: string;
            default: number;
            doc: string;
        };
        attribution: {
            type: string;
            doc: string;
        };
        buffer: {
            type: string;
            default: number;
            maximum: number;
            minimum: number;
            doc: string;
        };
        filter: {
            type: string;
            doc: string;
        };
        tolerance: {
            type: string;
            default: number;
            doc: string;
        };
        cluster: {
            type: string;
            default: boolean;
            doc: string;
        };
        clusterRadius: {
            type: string;
            default: number;
            minimum: number;
            doc: string;
        };
        clusterMaxZoom: {
            type: string;
            doc: string;
        };
        clusterMinPoints: {
            type: string;
            doc: string;
        };
        clusterProperties: {
            type: string;
            doc: string;
        };
        lineMetrics: {
            type: string;
            default: boolean;
            doc: string;
        };
        generateId: {
            type: string;
            default: boolean;
            doc: string;
        };
        promoteId: {
            type: string;
            doc: string;
        };
    };
    source_video: {
        type: {
            required: boolean;
            type: string;
            values: {
                video: {
                    doc: string;
                };
            };
            doc: string;
        };
        urls: {
            required: boolean;
            type: string;
            value: string;
            doc: string;
        };
        coordinates: {
            required: boolean;
            doc: string;
            type: string;
            length: number;
            value: {
                type: string;
                length: number;
                value: string;
                doc: string;
            };
        };
    };
    source_image: {
        type: {
            required: boolean;
            type: string;
            values: {
                image: {
                    doc: string;
                };
            };
            doc: string;
        };
        url: {
            required: boolean;
            type: string;
            doc: string;
        };
        coordinates: {
            required: boolean;
            doc: string;
            type: string;
            length: number;
            value: {
                type: string;
                length: number;
                value: string;
                doc: string;
            };
        };
    };
    layer: {
        id: {
            type: string;
            doc: string;
            required: boolean;
        };
        type: {
            type: string;
            values: {
                fill: {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
                line: {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
                symbol: {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
                circle: {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
                heatmap: {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
                "fill-extrusion": {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
                raster: {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
                hillshade: {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
                background: {
                    doc: string;
                    "sdk-support": {
                        "basic functionality": {
                            js: string;
                            android: string;
                            ios: string;
                            macos: string;
                        };
                    };
                };
            };
            doc: string;
            required: boolean;
        };
        metadata: {
            type: string;
            doc: string;
        };
        source: {
            type: string;
            doc: string;
        };
        "source-layer": {
            type: string;
            doc: string;
        };
        minzoom: {
            type: string;
            minimum: number;
            maximum: number;
            doc: string;
        };
        maxzoom: {
            type: string;
            minimum: number;
            maximum: number;
            doc: string;
        };
        filter: {
            type: string;
            doc: string;
        };
        layout: {
            type: string;
            doc: string;
        };
        paint: {
            type: string;
            doc: string;
        };
    };
    layout: string[];
    layout_background: {
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    layout_fill: {
        "fill-sort-key": {
            type: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    layout_circle: {
        "circle-sort-key": {
            type: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    layout_heatmap: {
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    "layout_fill-extrusion": {
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    layout_line: {
        "line-cap": {
            type: string;
            values: {
                butt: {
                    doc: string;
                };
                round: {
                    doc: string;
                };
                square: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-join": {
            type: string;
            values: {
                bevel: {
                    doc: string;
                };
                round: {
                    doc: string;
                };
                miter: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-miter-limit": {
            type: string;
            default: number;
            doc: string;
            requires: {
                "line-join": string;
            }[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-round-limit": {
            type: string;
            default: number;
            doc: string;
            requires: {
                "line-join": string;
            }[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-sort-key": {
            type: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    layout_symbol: {
        "symbol-placement": {
            type: string;
            values: {
                point: {
                    doc: string;
                };
                line: {
                    doc: string;
                };
                "line-center": {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "`line-center` value": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "symbol-spacing": {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
            requires: {
                "symbol-placement": string;
            }[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "symbol-avoid-edges": {
            type: string;
            default: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "symbol-sort-key": {
            type: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "symbol-z-order": {
            type: string;
            values: {
                auto: {
                    doc: string;
                };
                "viewport-y": {
                    doc: string;
                };
                source: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-allow-overlap": {
            type: string;
            default: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-ignore-placement": {
            type: string;
            default: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-optional": {
            type: string;
            default: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-rotation-alignment": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
                auto: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "`auto` value": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-size": {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-text-fit": {
            type: string;
            values: {
                none: {
                    doc: string;
                };
                width: {
                    doc: string;
                };
                height: {
                    doc: string;
                };
                both: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "stretchable icons": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-text-fit-padding": {
            type: string;
            value: string;
            length: number;
            default: number[];
            units: string;
            doc: string;
            requires: (string | {
                "icon-text-fit": string[];
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-image": {
            type: string;
            doc: string;
            tokens: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-rotate": {
            type: string;
            default: number;
            period: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-padding": {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-keep-upright": {
            type: string;
            default: boolean;
            doc: string;
            requires: (string | {
                "icon-rotation-alignment": string;
                "symbol-placement"?: undefined;
            } | {
                "symbol-placement": string[];
                "icon-rotation-alignment"?: undefined;
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-offset": {
            type: string;
            value: string;
            length: number;
            default: number[];
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-anchor": {
            type: string;
            values: {
                center: {
                    doc: string;
                };
                left: {
                    doc: string;
                };
                right: {
                    doc: string;
                };
                top: {
                    doc: string;
                };
                bottom: {
                    doc: string;
                };
                "top-left": {
                    doc: string;
                };
                "top-right": {
                    doc: string;
                };
                "bottom-left": {
                    doc: string;
                };
                "bottom-right": {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-pitch-alignment": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
                auto: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-pitch-alignment": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
                auto: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "`auto` value": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-rotation-alignment": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
                auto: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "`auto` value": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-field": {
            type: string;
            default: string;
            tokens: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-font": {
            type: string;
            value: string;
            default: string[];
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-size": {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-max-width": {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-line-height": {
            type: string;
            default: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-letter-spacing": {
            type: string;
            default: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-justify": {
            type: string;
            values: {
                auto: {
                    doc: string;
                };
                left: {
                    doc: string;
                };
                center: {
                    doc: string;
                };
                right: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                auto: {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-radial-offset": {
            type: string;
            units: string;
            default: number;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            requires: string[];
            "property-type": string;
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
        };
        "text-variable-anchor": {
            type: string;
            value: string;
            values: {
                center: {
                    doc: string;
                };
                left: {
                    doc: string;
                };
                right: {
                    doc: string;
                };
                top: {
                    doc: string;
                };
                bottom: {
                    doc: string;
                };
                "top-left": {
                    doc: string;
                };
                "top-right": {
                    doc: string;
                };
                "bottom-left": {
                    doc: string;
                };
                "bottom-right": {
                    doc: string;
                };
            };
            requires: (string | {
                "symbol-placement": string[];
            })[];
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-anchor": {
            type: string;
            values: {
                center: {
                    doc: string;
                };
                left: {
                    doc: string;
                };
                right: {
                    doc: string;
                };
                top: {
                    doc: string;
                };
                bottom: {
                    doc: string;
                };
                "top-left": {
                    doc: string;
                };
                "top-right": {
                    doc: string;
                };
                "bottom-left": {
                    doc: string;
                };
                "bottom-right": {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: (string | {
                "!": string;
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-max-angle": {
            type: string;
            default: number;
            units: string;
            doc: string;
            requires: (string | {
                "symbol-placement": string[];
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-writing-mode": {
            type: string;
            value: string;
            values: {
                horizontal: {
                    doc: string;
                };
                vertical: {
                    doc: string;
                };
            };
            doc: string;
            requires: (string | {
                "symbol-placement": string[];
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-rotate": {
            type: string;
            default: number;
            period: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-padding": {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-keep-upright": {
            type: string;
            default: boolean;
            doc: string;
            requires: (string | {
                "text-rotation-alignment": string;
                "symbol-placement"?: undefined;
            } | {
                "symbol-placement": string[];
                "text-rotation-alignment"?: undefined;
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-transform": {
            type: string;
            values: {
                none: {
                    doc: string;
                };
                uppercase: {
                    doc: string;
                };
                lowercase: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-offset": {
            type: string;
            doc: string;
            value: string;
            units: string;
            length: number;
            default: number[];
            requires: (string | {
                "!": string;
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-allow-overlap": {
            type: string;
            default: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-ignore-placement": {
            type: string;
            default: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-optional": {
            type: string;
            default: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    layout_raster: {
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    layout_hillshade: {
        visibility: {
            type: string;
            values: {
                visible: {
                    doc: string;
                };
                none: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            "property-type": string;
        };
    };
    filter: {
        type: string;
        value: string;
        doc: string;
    };
    filter_operator: {
        type: string;
        values: {
            "==": {
                doc: string;
            };
            "!=": {
                doc: string;
            };
            ">": {
                doc: string;
            };
            ">=": {
                doc: string;
            };
            "<": {
                doc: string;
            };
            "<=": {
                doc: string;
            };
            in: {
                doc: string;
            };
            "!in": {
                doc: string;
            };
            all: {
                doc: string;
            };
            any: {
                doc: string;
            };
            none: {
                doc: string;
            };
            has: {
                doc: string;
            };
            "!has": {
                doc: string;
            };
            within: {
                doc: string;
            };
        };
        doc: string;
    };
    geometry_type: {
        type: string;
        values: {
            Point: {
                doc: string;
            };
            LineString: {
                doc: string;
            };
            Polygon: {
                doc: string;
            };
        };
        doc: string;
    };
    function: {
        expression: {
            type: string;
            doc: string;
        };
        stops: {
            type: string;
            doc: string;
            value: string;
        };
        base: {
            type: string;
            default: number;
            minimum: number;
            doc: string;
        };
        property: {
            type: string;
            doc: string;
            default: string;
        };
        type: {
            type: string;
            values: {
                identity: {
                    doc: string;
                };
                exponential: {
                    doc: string;
                };
                interval: {
                    doc: string;
                };
                categorical: {
                    doc: string;
                };
            };
            doc: string;
            default: string;
        };
        colorSpace: {
            type: string;
            values: {
                rgb: {
                    doc: string;
                };
                lab: {
                    doc: string;
                };
                hcl: {
                    doc: string;
                };
            };
            doc: string;
            default: string;
        };
        default: {
            type: string;
            required: boolean;
            doc: string;
        };
    };
    function_stop: {
        type: string;
        minimum: number;
        maximum: number;
        value: string[];
        length: number;
        doc: string;
    };
    expression: {
        type: string;
        value: string;
        minimum: number;
        doc: string;
    };
    expression_name: {
        doc: string;
        type: string;
        values: {
            let: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            var: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            literal: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            array: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            at: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            in: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "index-of": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                    };
                };
            };
            slice: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                    };
                };
            };
            case: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            match: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            coalesce: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            step: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            interpolate: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "interpolate-hcl": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                    };
                };
            };
            "interpolate-lab": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                    };
                };
            };
            ln2: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            pi: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            e: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            typeof: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            string: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            number: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            boolean: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            object: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            collator: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            format: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    "text-font": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    "font-scale": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    "text-color": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    image: {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            image: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "number-format": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                    };
                };
            };
            "to-string": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "to-number": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "to-boolean": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "to-rgba": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "to-color": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            rgb: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            rgba: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            get: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            has: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            length: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            properties: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "feature-state": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                    };
                };
            };
            "geometry-type": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            id: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            zoom: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "heatmap-density": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "line-progress": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            accumulated: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                    };
                };
            };
            "+": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "*": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "-": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "/": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "%": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "^": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            sqrt: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            log10: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            ln: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            log2: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            sin: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            cos: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            tan: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            asin: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            acos: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            atan: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            min: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            max: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            round: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            abs: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            ceil: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            floor: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            distance: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "==": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    collator: {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "!=": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    collator: {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            ">": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    collator: {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "<": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    collator: {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            ">=": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    collator: {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "<=": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                    collator: {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            all: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            any: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "!": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            within: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "is-supported-script": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                    };
                };
            };
            upcase: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            downcase: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            concat: {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
            "resolved-locale": {
                doc: string;
                group: string;
                "sdk-support": {
                    "basic functionality": {
                        js: string;
                        android: string;
                        ios: string;
                        macos: string;
                    };
                };
            };
        };
    };
    light: {
        anchor: {
            type: string;
            default: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            "property-type": string;
            transition: boolean;
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            doc: string;
            example: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
        };
        position: {
            type: string;
            default: number[];
            length: number;
            value: string;
            "property-type": string;
            transition: boolean;
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            doc: string;
            example: number[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
        };
        color: {
            type: string;
            "property-type": string;
            default: string;
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            transition: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
        };
        intensity: {
            type: string;
            "property-type": string;
            default: number;
            minimum: number;
            maximum: number;
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            transition: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
        };
    };
    paint: string[];
    paint_fill: {
        "fill-antialias": {
            type: string;
            default: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-opacity": {
            type: string;
            default: number;
            minimum: number;
            maximum: number;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-color": {
            type: string;
            default: string;
            doc: string;
            transition: boolean;
            requires: {
                "!": string;
            }[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-outline-color": {
            type: string;
            doc: string;
            transition: boolean;
            requires: ({
                "!": string;
                "fill-antialias"?: undefined;
            } | {
                "fill-antialias": boolean;
                "!"?: undefined;
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-translate": {
            type: string;
            value: string;
            length: number;
            default: number[];
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-translate-anchor": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            doc: string;
            default: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-pattern": {
            type: string;
            transition: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    macos: string;
                    ios: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    "paint_fill-extrusion": {
        "fill-extrusion-opacity": {
            type: string;
            default: number;
            minimum: number;
            maximum: number;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-extrusion-color": {
            type: string;
            default: string;
            doc: string;
            transition: boolean;
            requires: {
                "!": string;
            }[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-extrusion-translate": {
            type: string;
            value: string;
            length: number;
            default: number[];
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-extrusion-translate-anchor": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            doc: string;
            default: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-extrusion-pattern": {
            type: string;
            transition: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    macos: string;
                    ios: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-extrusion-height": {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-extrusion-base": {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
            transition: boolean;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "fill-extrusion-vertical-gradient": {
            type: string;
            default: boolean;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    paint_line: {
        "line-opacity": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-color": {
            type: string;
            doc: string;
            default: string;
            transition: boolean;
            requires: {
                "!": string;
            }[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-translate": {
            type: string;
            value: string;
            length: number;
            default: number[];
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-translate-anchor": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            doc: string;
            default: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-width": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-gap-width": {
            type: string;
            default: number;
            minimum: number;
            doc: string;
            transition: boolean;
            units: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-offset": {
            type: string;
            default: number;
            doc: string;
            transition: boolean;
            units: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-blur": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-dasharray": {
            type: string;
            value: string;
            doc: string;
            minimum: number;
            transition: boolean;
            units: string;
            requires: {
                "!": string;
            }[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {};
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-pattern": {
            type: string;
            transition: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    macos: string;
                    ios: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "line-gradient": {
            type: string;
            doc: string;
            transition: boolean;
            requires: ({
                "!": string;
                source?: undefined;
                has?: undefined;
            } | {
                source: string;
                has: {
                    lineMetrics: boolean;
                };
                "!"?: undefined;
            })[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {};
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    paint_circle: {
        "circle-radius": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-color": {
            type: string;
            default: string;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-blur": {
            type: string;
            default: number;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-opacity": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-translate": {
            type: string;
            value: string;
            length: number;
            default: number[];
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-translate-anchor": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            doc: string;
            default: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-pitch-scale": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-pitch-alignment": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-stroke-width": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-stroke-color": {
            type: string;
            default: string;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "circle-stroke-opacity": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    paint_heatmap: {
        "heatmap-radius": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "heatmap-weight": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "heatmap-intensity": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "heatmap-color": {
            type: string;
            default: (string | number | string[])[];
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {};
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "heatmap-opacity": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    paint_symbol: {
        "icon-opacity": {
            doc: string;
            type: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-color": {
            type: string;
            default: string;
            transition: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-halo-color": {
            type: string;
            default: string;
            transition: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-halo-width": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-halo-blur": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-translate": {
            type: string;
            value: string;
            length: number;
            default: number[];
            transition: boolean;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "icon-translate-anchor": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            doc: string;
            default: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-opacity": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-color": {
            type: string;
            doc: string;
            default: string;
            transition: boolean;
            overridable: boolean;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-halo-color": {
            type: string;
            default: string;
            transition: boolean;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-halo-width": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-halo-blur": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-translate": {
            type: string;
            value: string;
            length: number;
            default: number[];
            transition: boolean;
            units: string;
            doc: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "text-translate-anchor": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            doc: string;
            default: string;
            requires: string[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    paint_raster: {
        "raster-opacity": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "raster-hue-rotate": {
            type: string;
            default: number;
            period: number;
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "raster-brightness-min": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "raster-brightness-max": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "raster-saturation": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "raster-contrast": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "raster-resampling": {
            type: string;
            doc: string;
            values: {
                linear: {
                    doc: string;
                };
                nearest: {
                    doc: string;
                };
            };
            default: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "raster-fade-duration": {
            type: string;
            default: number;
            minimum: number;
            transition: boolean;
            units: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    paint_hillshade: {
        "hillshade-illumination-direction": {
            type: string;
            default: number;
            minimum: number;
            maximum: number;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "hillshade-illumination-anchor": {
            type: string;
            values: {
                map: {
                    doc: string;
                };
                viewport: {
                    doc: string;
                };
            };
            default: string;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "hillshade-exaggeration": {
            type: string;
            doc: string;
            default: number;
            minimum: number;
            maximum: number;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "hillshade-shadow-color": {
            type: string;
            default: string;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "hillshade-highlight-color": {
            type: string;
            default: string;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "hillshade-accent-color": {
            type: string;
            default: string;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    paint_background: {
        "background-color": {
            type: string;
            default: string;
            doc: string;
            transition: boolean;
            requires: {
                "!": string;
            }[];
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "background-pattern": {
            type: string;
            transition: boolean;
            doc: string;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
                "data-driven styling": {};
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
        "background-opacity": {
            type: string;
            default: number;
            minimum: number;
            maximum: number;
            doc: string;
            transition: boolean;
            "sdk-support": {
                "basic functionality": {
                    js: string;
                    android: string;
                    ios: string;
                    macos: string;
                };
            };
            expression: {
                interpolated: boolean;
                parameters: string[];
            };
            "property-type": string;
        };
    };
    transition: {
        duration: {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
        };
        delay: {
            type: string;
            default: number;
            minimum: number;
            units: string;
            doc: string;
        };
    };
    "property-type": {
        "data-driven": {
            type: string;
            doc: string;
        };
        "cross-faded": {
            type: string;
            doc: string;
        };
        "cross-faded-data-driven": {
            type: string;
            doc: string;
        };
        "color-ramp": {
            type: string;
            doc: string;
        };
        "data-constant": {
            type: string;
            doc: string;
        };
        constant: {
            type: string;
            doc: string;
        };
    };
    promoteId: {
        "*": {
            type: string;
            doc: string;
        };
    };
}): any[];
declare namespace validateStyleMin {
    var source: (...args: any[]) => any[];
    var light: (...args: any[]) => any[];
    var layer: (...args: any[]) => any[];
    var filter: (...args: any[]) => any[];
    var paintProperty: (...args: any[]) => any[];
    var layoutProperty: (...args: any[]) => any[];
}
export default validateStyleMin;
//# sourceMappingURL=validate_style.min.d.ts.map